#
# spec file for package python-dbus_next
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define modname python-dbus-next
Name:           python-dbus_next
Version:        0.2.3
Release:        1.11
Summary:        A zero-dependency DBus library for Python with asyncio support
License:        MIT
URL:            https://github.com/altdesktop/python-dbus-next
Source0:        https://github.com/altdesktop/python-dbus-next/archive/v%{version}/%{modname}-%{version}.tar.gz
Source99:       python-dbus_next-rpmlintrc
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch

%python_subpackages

%description
python-dbus-next is a Python library for DBus that aims to be a fully featured high level library primarily geared towards integration of applications into Linux desktop and mobile environments.

Desktop application developers can use this library for integrating their applications into desktop environments by implementing common DBus standard interfaces or creating custom plugin interfaces.

Desktop users can use this library to create their own scripts and utilities to interact with those interfaces for customization of their desktop environment.

python-dbus-next plans to improve over other DBus libraries for Python in the following ways:

Zero dependencies and pure Python 3.
Support for multiple IO backends including asyncio and the GLib main loop.
Nonblocking IO suitable for GUI development.
Target the latest language features of Python for beautiful services and clients.
Complete implementation of the DBus type system without ever guessing types.
Integration tests for all features of the library.
Completely documented public API.

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Test are only supported inside provided docker container. https://github.com/altdesktop/python-dbus-next/issues/94#issuecomment-881654674

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Wed Sep 29 2021 Matej Cepl <mcepl@suse.com>
- Add python-dbus_next-rpmlintrc as another Source.
* Tue Sep 28 2021 nyslay@gmail.com
- Update to version 0.2.3:
  * Include py.typed in Manifest.in (#79)
  * Fix property validation error message (#81)
  * Don't log errors if call failed after disconnect (#84)
  * Support PEP563 annotations (#3)
  * Service: support async properties (#86)
  * Client: Support coroutines as signal handlers (#58)
* Tue Sep 28 2021 nyslay@gmail.com
- Update to version 0.2.2:
  * Add connected instance variable to the MessageBus (#74)
  * Better handling of message bus errors on disconnect (de8ed30)
  * Ensure futures are not done when settings results and exceptions (#73, 1213667)
* Tue Sep 28 2021 nyslay@gmail.com
- Update to version 0.2.1
  * aio.MessageBus: Support passing unix fds. (#54)
  * Unmarshaller optimizations for a significant performance increase in message reading. (#62, #64)
  * Cache instances of SignatureTree. (ace5584)
  * Fix socket creation on macos. (#63)
  * Implement PEP 561 to indicate inline type hints. (#69)
  * aio.MessageBus: Return a future from send(). (302511b)
  * aio.MessageBus: Add wait_for_disconnect() to detect connection errors. (ab01ab1)
* Tue Sep 28 2021 nyslay@gmail.com
- Updated to version 0.1.4
  * Support tcp transport addresses (#57)
  * Add support for the annonymous authentication protocol (#32)
  * Add flags kwarg to aio high level client method call (#55)
  * Allow subclassing of DBusError (#42)
  * Fix exception in aio message handler loop on task cancellation (ff165aa)
  * Improve error messages (#46, #59)
  * Fix match rule memory leak bug (508edf8)
  * Don't add match rules for high level client by default (615218f)
  * Add empty properties interface to standard interfaces (#49)
* Tue Sep 28 2021 nyslay@gmail.com
- Updated to version 0.1.3
  * Add the object manager interface to the service. (#14, #37)
  * Allow coroutines in service methods. (#24, #27)
  * Client: don't send method replies with NO_REPLY_EXPECTED message flag. (#22)
  * Fix duplicate nodes in introspection. (#13)
* Tue Sep 28 2021 nyslay@gmail.com
- Updated to version 0.1.2
  * Allow exporting interface multiple times (#4)
  * Fix super call in exceptions (#5)
  * Add timeout support on introspect (#7)
  * Add unix fd type 'h' to valid tokens (#9)
  * Dont use future annotations (#10)
  * Fix variant validator (d724fc2)
* Tue Sep 28 2021 nyslay@gmail.com
- Updated to version 0.1.1
  * Remove the MessageBus convenience constructors (breaking).
  * Complete documentation.
  * Type annotation for all public methods.
* Tue Sep 28 2021 nyslay@gmail.com
- This is the first release of python-dbus-next.
